@@ -26,7 +26,6 @@
 
 #include <kalarmcal/kaevent.h>
 
-#include <AkonadiCore/collection.h>
 #include <KCalendarCore/FileStorage>
 #include <KCalendarCore/Event>
 
@@ -64,12 +63,11 @@ class AlarmCalendar : public QObject
         KAEvent*              event(const EventId& uniqueId, bool checkDuplicates = false);
         KAEvent*              templateEvent(const QString& templateName);
         KAEvent::List         events(const QString& uniqueId) const;
-        KAEvent::List         events(CalEvent::Types s = CalEvent::EMPTY) const  { return events(Akonadi::Collection(), s); }
-        KAEvent::List         events(const Akonadi::Collection&, CalEvent::Types = CalEvent::EMPTY) const;
+        KAEvent::List         events(CalEvent::Types s = CalEvent::EMPTY) const  { return events(Resource(), s); }
+        KAEvent::List         events(const Resource&, CalEvent::Types = CalEvent::EMPTY) const;
         KCalendarCore::Event::List kcalEvents(CalEvent::Type s = CalEvent::EMPTY);   // display calendar only
-        bool                  eventReadOnly(Akonadi::Item::Id) const;
-        Akonadi::Collection   collectionForEvent(Akonadi::Item::Id) const;
-        bool                  addEvent(KAEvent&, QWidget* promptparent = nullptr, bool useEventID = false, Akonadi::Collection* = nullptr, bool noPrompt = false, bool* cancelled = nullptr);
+        bool                  eventReadOnly(const QString& eventId) const;
+        bool                  addEvent(KAEvent&, QWidget* promptparent = nullptr, bool useEventID = false, Resource* = nullptr, bool noPrompt = false, bool* cancelled = nullptr);
         bool                  modifyEvent(const EventId& oldEventId, KAEvent& newEvent);
         KAEvent*              updateEvent(const KAEvent&);
         KAEvent*              updateEvent(const KAEvent*);
@@ -87,7 +85,7 @@ class AlarmCalendar : public QObject
         static AlarmCalendar* displayCalendar()      { return mDisplayCalendar; }
         static AlarmCalendar* displayCalendarOpen();
         static KAEvent*       getEvent(const EventId&);
-        bool                  importAlarms(QWidget*, Akonadi::Collection* = nullptr);
+        bool                  importAlarms(QWidget*, Resource* = nullptr);
         static bool           exportAlarms(const KAEvent::List&, QWidget* parent);
 
     Q_SIGNALS:
@@ -97,32 +95,30 @@ class AlarmCalendar : public QObject
         void                  calendarSaved(AlarmCalendar*);
 
     private Q_SLOTS:
-        void                  slotCollectionStatusChanged(const Akonadi::Collection&, AkonadiModel::Change,
-                                                          const QVariant& value, bool inserted);
-        void                  slotCollectionsPopulated();
-        void                  slotEventsAdded(const AkonadiModel::EventList&);
-        void                  slotEventsToBeRemoved(const AkonadiModel::EventList&);
-        void                  slotEventChanged(const AkonadiModel::Event&);
+        void                  slotResourceSettingsChanged(Resource&, ResourceType::Changes);
+        void                  slotResourcesPopulated();
+        void                  slotEventsAdded(Resource&, const QList<KAEvent>&);
+        void                  slotEventsToBeRemoved(Resource&, const QList<KAEvent>&);
+        void                  slotEventUpdated(Resource&, const KAEvent&);
     private:
         enum CalType { RESOURCES, LOCAL_ICAL, LOCAL_VCAL };
-        typedef QMap<Akonadi::Collection::Id, KAEvent::List> ResourceMap;  // id = invalid for display calendar
-        typedef QMap<Akonadi::Collection::Id, KAEvent*> EarliestMap;
-        typedef QHash<EventId, KAEvent*> KAEventMap;  // indexed by collection and event UID
+        typedef QMap<ResourceId, KAEvent::List> ResourceMap;  // id = invalid for display calendar
+        typedef QMap<ResourceId, KAEvent*> EarliestMap;
+        typedef QHash<EventId, KAEvent*> KAEventMap;  // indexed by resource and event UID
 
         AlarmCalendar();
         AlarmCalendar(const QString& file, CalEvent::Type);
         bool                  saveCal(const QString& newFile = QString());
         bool                  isValid() const   { return mCalType == RESOURCES || mCalendarStorage; }
-        void                  addNewEvent(const Akonadi::Collection&, KAEvent*, bool replace = false);
+        void                  addNewEvent(const Resource&, KAEvent*, bool replace = false);
         CalEvent::Type        deleteEventInternal(const KAEvent&, bool deleteFromAkonadi = true);
-        CalEvent::Type        deleteEventInternal(const KAEvent&, const Akonadi::Collection&,
-                                                   bool deleteFromAkonadi = true);
-        CalEvent::Type        deleteEventInternal(const QString& eventID, const KAEvent& = KAEvent(),
-                                                   const Akonadi::Collection& = Akonadi::Collection(), bool deleteFromAkonadi = true);
+        CalEvent::Type        deleteEventInternal(const KAEvent&, Resource&, bool deleteFromAkonadi = true);
+        CalEvent::Type        deleteEventInternal(const QString& eventID, const KAEvent&, Resource&,
+                                                  bool deleteFromAkonadi = true);
         void                  updateDisplayKAEvents();
-        void                  removeKAEvents(Akonadi::Collection::Id, bool closing = false, CalEvent::Types = CalEvent::ACTIVE | CalEvent::ARCHIVED | CalEvent::TEMPLATE);
-        void                  findEarliestAlarm(const Akonadi::Collection&);
-        void                  findEarliestAlarm(Akonadi::Collection::Id);  //deprecated
+        void                  removeKAEvents(ResourceId, bool closing = false, CalEvent::Types = CalEvent::ACTIVE | CalEvent::ARCHIVED | CalEvent::TEMPLATE);
+        void                  findEarliestAlarm(const Resource&);
+        void                  findEarliestAlarm(ResourceId);  //deprecated
         void                  checkForDisabledAlarms();
         void                  checkForDisabledAlarms(bool oldEnabled, bool newEnabled);
 
@@ -139,12 +135,12 @@ class AlarmCalendar : public QObject
         QUrl                  mICalUrl;            // URL of iCalendar file
         QString               mLocalFile;          // calendar file, or local copy if it's a remote file
         CalType               mCalType;            // what type of calendar mCalendar is (resources/ical/vcal)
-        CalEvent::Type        mEventType;         // what type of events the calendar file is for
-        bool                  mOpen;               // true if the calendar file is open
+        CalEvent::Type        mEventType;          // what type of events the calendar file is for
+        bool                  mOpen{false};        // true if the calendar file is open
         bool                  mIgnoreAtLogin{false}; // ignore new/updated repeat-at-login alarms
-        int                   mUpdateCount;        // nesting level of group of calendar update calls
-        bool                  mUpdateSave;         // save() was called while mUpdateCount > 0
-        bool                  mHaveDisabledAlarms; // there is at least one individually disabled alarm
+        int                   mUpdateCount{0};     // nesting level of group of calendar update calls
+        bool                  mUpdateSave{false};  // save() was called while mUpdateCount > 0
+        bool                  mHaveDisabledAlarms{false}; // there is at least one individually disabled alarm
 
         using QObject::event;   // prevent "hidden" warning
 };
