@@ -1,7 +1,7 @@
 /*
  *  editdlg.h  -  dialog to create or modify an alarm or alarm template
  *  Program:  kalarm
- *  Copyright © 2001-2015 by David Jarvie <djarvie@kde.org>
+ *  Copyright © 2001-2019 David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,12 +21,12 @@
 #ifndef EDITDLG_H
 #define EDITDLG_H
 
+#include <resources/resource.h>
+
 #include <kalarmcal/alarmtext.h>
 #include <kalarmcal/datetime.h>
 #include <kalarmcal/kaevent.h>
 
-#include <AkonadiCore/collection.h>
-
 #include <QDialog>
 #include <QTime>
 
@@ -70,7 +70,7 @@ class EditAlarmDlg : public QDialog
         static EditAlarmDlg* create(bool Template, const KAEvent*, bool newAlarm, QWidget* parent = nullptr,
                                     GetResourceType = RES_PROMPT, bool readOnly = false);
         ~EditAlarmDlg() override;
-        bool            getEvent(KAEvent&, Akonadi::Collection&);
+        bool            getEvent(KAEvent&, Resource&);
 
         // Methods to initialise values in the New Alarm dialogue.
         // N.B. setTime() must be called first to set the date-only characteristic,
@@ -155,7 +155,7 @@ class EditAlarmDlg : public QDialog
 
         QDialogButtonBox*   mButtonBox;
         QAbstractButton*    mTryButton;
-        QAbstractButton*    mLoadTemplateButton;
+        QAbstractButton*    mLoadTemplateButton{nullptr};
         QAbstractButton*    mMoreLessButton;
 
     private:
@@ -164,51 +164,52 @@ class EditAlarmDlg : public QDialog
         StackedScrollGroup* mTabScrollGroup;
         int                 mMainPageIndex;
         int                 mRecurPageIndex;
-        bool                mMainPageShown;            // true once the main tab has been displayed
-        bool                mRecurPageShown;           // true once the recurrence tab has been displayed
-        bool                mRecurSetDefaultEndDate;   // adjust default end date/time when recurrence tab is displayed
+        bool                mMainPageShown{false};           // true once the main tab has been displayed
+        bool                mRecurPageShown{false};          // true once the recurrence tab has been displayed
+        bool                mRecurSetDefaultEndDate{true};   // adjust default end date/time when recurrence tab is displayed
 
         // Templates
-        QLineEdit*          mTemplateName;
+        QLineEdit*          mTemplateName{nullptr};
         ButtonGroup*        mTemplateTimeGroup;
         RadioButton*        mTemplateDefaultTime; // no alarm time is specified
         RadioButton*        mTemplateUseTimeAfter;// alarm time is specified as an offset from current
         RadioButton*        mTemplateAnyTime;     // alarms have date only, no time
         RadioButton*        mTemplateUseTime;     // an alarm time is specified
         TimeSpinBox*        mTemplateTimeAfter;   // the specified offset from the current time
-        TimeEdit*           mTemplateTime;        // the alarm time which is specified 
-        QGroupBox*          mDeferGroup;
+        TimeEdit*           mTemplateTime;        // the alarm time which is specified
+        QGroupBox*          mDeferGroup{nullptr};
         QLabel*             mDeferTimeLabel;
-        QPushButton*        mDeferChangeButton;
+        QPushButton*        mDeferChangeButton{nullptr};
 
-        AlarmTimeWidget*    mTimeWidget;
+        AlarmTimeWidget*    mTimeWidget{nullptr};
         LateCancelSelector* mLateCancel;
-        Reminder*           mReminder;           // null except for display alarms
-        CheckBox*           mShowInKorganizer;
+        Reminder*           mReminder;             // null except for display alarms
+        CheckBox*           mShowInKorganizer{nullptr};
 
-        QFrame*             mMoreOptions;        // contains options hidden by default
+        QFrame*             mMoreOptions;          // contains options hidden by default
 
         RecurrenceEdit*     mRecurrenceEdit;
 
-        QString             mAlarmMessage;       // message text/file name/command/email message
+        QString             mAlarmMessage;         // message text/file name/command/email message
         DateTime            mAlarmDateTime;
         DateTime            mDeferDateTime;
-        Akonadi::Item::Id   mCollectionItemId;   // if >=0, save alarm in collection containing this item ID
-        Akonadi::Collection mCollection;         // collection to save event into, or null
-        int                 mDeferGroupHeight;   // height added by deferred time widget
-        int                 mDesktop;            // desktop to display the dialog in
-        QString             mEventId;            // UID of event being edited, or blank for new event
-        bool                mTemplate;           // editing an alarm template
-        bool                mNewAlarm;           // editing a new alarm
-        bool                mExpiredRecurrence;  // initially a recurrence which has expired
-        mutable bool        mChanged;            // controls other than deferral have changed since dialog was displayed
-        mutable bool        mOnlyDeferred;       // the only change made in the dialog was to the existing deferral
-        bool                mDesiredReadOnly;    // the specified read-only status of the dialog
-        bool                mReadOnly;           // the actual read-only status of the dialog
-        bool                mShowingMore;        // the More Options button has been clicked
+        bool                mUseResourceEventId;   // whether to use mResourceEventId
+        QString             mResourceEventId;      // if non-null, save alarm in resource containing this event ID
+        Resource            mResource;             // resource to save event into, or invalid
+        int                 mDeferGroupHeight{0};  // height added by deferred time widget
+        int                 mDesktop;              // desktop to display the dialog in
+        QString             mEventId;              // UID of event being edited, or blank for new event
+        bool                mTemplate;             // editing an alarm template
+        bool                mNewAlarm;             // editing a new alarm
+        bool                mExpiredRecurrence;    // initially a recurrence which has expired
+        mutable bool        mChanged;              // controls other than deferral have changed since dialog was displayed
+        mutable bool        mOnlyDeferred;         // the only change made in the dialog was to the existing deferral
+        bool                mDesiredReadOnly;      // the specified read-only status of the dialog
+        bool                mReadOnly;             // the actual read-only status of the dialog
+        bool                mShowingMore{true};    // the More Options button has been clicked
 
         // Initial state of all controls
-        KAEvent*            mSavedEvent;
+        KAEvent*            mSavedEvent{nullptr};
         QString             mSavedTemplateName;     // mTemplateName value
         QAbstractButton*    mSavedTemplateTimeType; // selected button in mTemplateTimeGroup
         QTime               mSavedTemplateTime;     // mTemplateTime value
