@@ -1,7 +1,7 @@
 /*
  *  specialactions.cpp  -  widget to specify special alarm actions
  *  Program:  kalarm
- *  Copyright © 2004-2009,2012 by David Jarvie <djarvie@kde.org>
+ *  Copyright © 2004-2019 David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,13 +18,13 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#include "kalarm.h"
 #include "specialactions.h"
 
 #include "autoqpointer.h"
 #include "checkbox.h"
 #include "functions.h"
 #include "shellprocess.h"
+#include "kalarm_debug.h"
 
 #include <KLocalizedString>
 
@@ -36,7 +36,6 @@
 #include <QDialogButtonBox>
 #include <QPushButton>
 #include <QLineEdit>
-#include "kalarm_debug.h"
 
 
 /*=============================================================================
@@ -45,10 +44,9 @@
 =============================================================================*/
 
 SpecialActionsButton::SpecialActionsButton(bool enableCheckboxes, QWidget* parent)
-    : QPushButton(i18nc("@action:button", "Special Actions..."), parent),
-      mOptions{},
-      mEnableCheckboxes(enableCheckboxes),
-      mReadOnly(false)
+    : QPushButton(i18nc("@action:button", "Special Actions..."), parent)
+    , mOptions{}
+    , mEnableCheckboxes(enableCheckboxes)
 {
     setCheckable(true);
     setChecked(false);
@@ -158,9 +156,8 @@ void SpecialActionsDlg::resizeEvent(QResizeEvent* re)
 =============================================================================*/
 
 SpecialActions::SpecialActions(bool enableCheckboxes, QWidget* parent)
-    : QWidget(parent),
-      mEnableCheckboxes(enableCheckboxes),
-      mReadOnly(false)
+    : QWidget(parent)
+    , mEnableCheckboxes(enableCheckboxes)
 {
     QVBoxLayout* topLayout = new QVBoxLayout(this);
     topLayout->setContentsMargins(0, 0, 0, 0);
@@ -274,6 +271,4 @@ void SpecialActions::slotPreActionChanged(const QString& text)
     }
 }
 
-
-
 // vim: et sw=4:
